@@ -56,6 +56,13 @@ pub mod compose;
 mod build;
 mod val_helpr;
 
+/// `block_elements` will be renamed to `elements` before 1.0.0.
+pub use block_elements as elems;
+#[doc(inline)]
+pub use block_elements::BlockElement;
+#[doc(inline)]
+pub use blocks::Block;
+#[doc(inline)]
 pub use compose::text;
 
 mod macros {
